@@ -11,6 +11,7 @@ import urllib3
 from uuid import getnode as get_mac
 import sys
 from pathlib import Path
+import subprocess
 
 downloads_path = str(Path.home() / "Downloads")
 
@@ -216,12 +217,34 @@ def current_milli_time():
     return int(time() * 1000)
 
 
+def exec_command(cmd):
+    return subprocess.getoutput(cmd)
+
+
+def get_git_name():
+    return exec_command("git config user.name")
+
+
+def get_git_email():
+    return exec_command("git config user.email")
+
+
+def get_name():
+    email = get_git_email()
+    name = get_git_name()
+    if email:
+        return email
+    else:
+        return name
+
+
 def mobExecuteMethodEvent(key, duration):
     http = urllib3.PoolManager()
     PARAMS = {"event": "execute_method",
               "key": key,
               "id": MAC_ADDRESS,
               "client": "CLI",
+              "name": get_name(),
               "duration": duration,
               "time_stamp": current_milli_time()
               }
@@ -231,5 +254,6 @@ def mobExecuteMethodEvent(key, duration):
 def mobLoadTasks(duration):
     http = urllib3.PoolManager()
     PARAMS = {"event": "load_tasks", "client": "CLI", "id": MAC_ADDRESS, "duration": duration,
+              "name": get_name(),
               "time_stamp": current_milli_time()}
     http.request('GET', URL, fields=PARAMS)
